# Get current account id and region.
locals {
  account_id = data.aws_caller_identity.current.account_id
  region     = data.aws_region.current_region.name
}

#glue database
resource "aws_glue_catalog_database" "aws_glue_catalog_database" {
  name = var.database_name
}

resource "aws_iam_policy" "glue-database-access-policy" {
  count       = var.enable_iam_policies ? 1 : 0
  name        = "${var.iam_policy_prefix}-access-policy"
  path        = "/"
  description = "Glue Database Access policy"

  policy = <<EOF
{
    "Version": "2012-10-17",
    "Statement": [
        {
            "Effect": "Allow",
            "Action": [
                "glue:Get*",
                "glue:List*",
                "glue:Search*",
                "glue:Create*",
                "glue:Update*",
                "glue:BatchGet*",
                "glue:BatchCreate*",
                "glue:BatchStop*",
                "glue:BatchUpdate*"
            ],
            "Resource": [
                "${aws_glue_catalog_database.aws_glue_catalog_database.arn}",
                "arn:aws:glue:${local.region}:${local.account_id}:catalog",
                "arn:aws:glue:${local.region}:${local.account_id}:table/${var.database_name}/*"
            ]
        }       
    ]
}
EOF
  lifecycle {
    ignore_changes = [
      description,
    ]
  }

  tags = var.tags
}

data "aws_caller_identity" "current" {}
data "aws_region" "current_region" {}